using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Input.Touch;
using Microsoft.Xna.Framework.Media;
using Microsoft.Devices;

namespace P7_2
{
    /// <summary>
    /// Это главный тип игры
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        spriteComp gameObject;
        //Для хранения ID касаний
        int gameObjectId;
        //Изображение для вывода
        Texture2D texture;
        //Следует ли перемещать объект
        bool gameObjectMove;
        
        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
            graphics.IsFullScreen = true;
            // Частота кадра на Windows Phone по умолчанию — 30 кадров в секунду.
            TargetElapsedTime = TimeSpan.FromTicks(333333);
            // Дополнительный заряд аккумулятора заблокирован.
            InactiveSleepTime = TimeSpan.FromSeconds(1);
            //Включить обработку жестов - FreeDarag и DoubleTap
            TouchPanel.EnabledGestures = GestureType.FreeDrag | GestureType.DoubleTap;
        }

        /// <summary>
        /// Позволяет игре выполнить инициализацию, необходимую перед запуском.
        /// Здесь можно запросить нужные службы и загрузить неграфический
        /// контент.  Вызов base.Initialize приведет к перебору всех компонентов и
        /// их инициализации.
        /// </summary>
        protected override void Initialize()
        {
            // ЗАДАЧА: добавьте здесь логику инициализации

            base.Initialize();
        }

        /// <summary>
        /// LoadContent будет вызываться в игре один раз; здесь загружается
        /// весь контент.
        /// </summary>
        protected override void LoadContent()
        {
            // Создайте новый SpriteBatch, который можно использовать для отрисовки текстур.
            spriteBatch = new SpriteBatch(GraphicsDevice);
            Services.AddService(typeof(SpriteBatch), spriteBatch);
            texture = Content.Load<Texture2D>("rectangle");
            //Создаём игровой объект
            CreateNewObject();
        }

        protected void CreateNewObject()
        {
            gameObject = new spriteComp(this, ref texture,
                new Rectangle(0, 0, 150, 100),
                new Vector2(0, 0));
            Components.Add(gameObject);
        }


        /// <summary>
        /// UnloadContent будет вызываться в игре один раз; здесь выгружается
        /// весь контент.
        /// </summary>
        protected override void UnloadContent()
        {
            // ЗАДАЧА: выгрузите здесь весь контент, не относящийся к ContentManager
        }

        /// <summary>
        /// Позволяет игре запускать логику обновления мира,
        /// проверки столкновений, получения ввода и воспроизведения звуков.
        /// </summary>
        /// <param name="gameTime">Предоставляет моментальный снимок значений времени.</param>
        protected override void Update(GameTime gameTime)
        {
            // Позволяет выйти из игры
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();
            //Получаем коллекцию объектов, содержащих информацию о касаниях экрана
            TouchCollection touchLocations = TouchPanel.GetState();
            //Перебираем коллекцию, присваивая объекту координаты касания
            foreach (TouchLocation touchLocation in touchLocations)
            {
                //Если обнаружено касание в области, соответствующей игровому объекту
                if (touchLocation.State == TouchLocationState.Pressed)
                {
                    if (touchLocation.Position.X > gameObject.GetSprPos().X &&
                        touchLocation.Position.X < gameObject.GetSprPos().X + gameObject.GetSprRectangle().Width &&
                        touchLocation.Position.Y > gameObject.GetSprPos().Y &&
                        touchLocation.Position.Y < gameObject.GetSprPos().Y + gameObject.GetSprRectangle().Height)
                    {
                        //Разрешаем перемещать объект
                        gameObjectMove = true;
                        //Запоминаем идентификатор касания
                        gameObjectId = touchLocation.Id;
                        
                    }
                }

                //Если касание окончилось
                if (touchLocation.State == TouchLocationState.Released)
                {
                    //Проверяем ID
                    if (gameObjectId == touchLocation.Id)
                    {
                        //Запрещаем перемещение
                        gameObjectMove = false;
                    }
                }

            }
            //До тех пор, пока разрешена обработка жестов
            while (TouchPanel.IsGestureAvailable)
            {
                //прочитаем жест
                GestureSample gs = TouchPanel.ReadGesture();
                //Если жест - FreeDrag и разрешено перемещение 
                //то есть, пользователь касается объекта на экране
                if (gs.GestureType == GestureType.FreeDrag && gameObjectMove==true)
                {
                    //Начнем перемещать объект со скоростью, заданной параметром Delta
                    //Фактически - чем быстрее был выполнен жест - тем быстрее будет двигаться объект
                    //в направлении жеста
                    gameObject.Move(gs.Delta);
                    
                }
                //Если обнаружен жест двойного касания экрана
                if (gs.GestureType == GestureType.DoubleTap)
                {
                    //Остановим движение объекта
                    gameObject.Move(new Vector2());
                    //Включим вибраацию на 0,1 секунды
                    VibrateController.Default.Start(TimeSpan.FromMilliseconds(100));
                }
         
            }
            base.Update(gameTime);
        }

        /// <summary>
        /// Вызывается, когда игра отрисовывается.
        /// </summary>
        /// <param name="gameTime">Предоставляет моментальный снимок значений времени.</param>
        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.CornflowerBlue);
            spriteBatch.Begin();
            base.Draw(gameTime);
            spriteBatch.End();
        }
       
    }
}
